--[[-----------------------------------------------------------------------------
HeadCount Boss Item Widget
-------------------------------------------------------------------------------]]
local Type, Version = "HeadCountRaidItem", 1
local AceGUI = LibStub and LibStub("AceGUI-3.0", true)
if not AceGUI or (AceGUI:GetWidgetVersion(Type) or 0) >= Version then return end

-- Lua APIs
local max, select, pairs = math.max, select, pairs

-- WoW APIs
local CreateFrame, UIParent = CreateFrame, UIParent


--[[-----------------------------------------------------------------------------
Methods
-------------------------------------------------------------------------------]]
local methods = {
	["OnAcquire"] = function(self)
		-- height is set dynamically by the text and image size
		self:SetNumber()
		self:SetDate()
		self:SetZone()
		self:SetSelected(false)
	end,

	-- ["OnRelease"] = nil,

	["OnWidthSet"] = function(self, width)
	end,

	["SetNumber"] = function(self, number)
		self.rowNumber = number
		self.numLabel:SetText(number)
	end,

	["SetDate"] = function(self,date)
		self.dateLabel:SetText(date)
	end,

	["SetBoss"] = function(self,zone)
		self.nameLabel:SetText(zone)
	end,

	["SetMembers"] = function(self,zone)
		self.memberLabel:SetText(zone)
	end,

	["SetSelected"] = function(self, value)
		if value then
			self.selectedRow:Show()
		else
			self.selectedRow:Hide()
		end
	end,

	["SetRaidID"] = function(self, value)
		self.raidID = value
	end,

}

local function HitArea_OnEnter(frame)
	frame.obj.highlight:Show()
end

local function HitArea_OnClick(frame)
	frame.obj:Fire("BossSelected",frame.obj.raidID, frame.obj.rowNumber)
end

local function HitArea_OnLeave(frame)
	GameTooltip:Hide()
	frame.obj.highlight:Hide()
end

local function Delete_OnClick(frame)
	frame.obj:Fire("BossDeleted",frame.obj.raidID)
end
local function Button_OnLeave(frame)
	GameTooltip:Hide()
end

local function Button_OnEnter(frame)
	if frame.tt then
		GameTooltip:SetOwner(frame,"ANCHOR_RIGHT", -6, 0)
		GameTooltip:AddLine(frame.tt)
		GameTooltip:Show()
	end
end

--[[-----------------------------------------------------------------------------
Constructor
-------------------------------------------------------------------------------]]
local function Constructor()
	local frame = CreateFrame("Frame", nil, UIParent)
	frame:Hide()
	frame:SetWidth(596)
	frame:SetHeight(18)

	local numLabel = frame:CreateFontString(nil,"ARTWORK", "GameFontNormalSmall")
	numLabel:SetWidth(28)
	numLabel:SetHeight(16)
	numLabel:SetJustifyH("LEFT")
	numLabel:SetTextColor(1,1,1,1)
	numLabel:SetPoint("TOPLEFT",8,0)

	local dateLabel = frame:CreateFontString(nil,"ARTWORK","GameFontNormalSmall")
	dateLabel:SetWidth(124)
	dateLabel:SetHeight(16)
	dateLabel:SetJustifyH("LEFT")
	dateLabel:SetTextColor(1,1,1,1)
	dateLabel:SetPoint("TOPLEFT",38,0)

	local memberLabel = frame:CreateFontString(nil,"ARTWORK","GameFontNormalSmall")
	memberLabel:SetWidth(28)
	memberLabel:SetHeight(16)
	memberLabel:SetJustifyH("LEFT")
	memberLabel:SetTextColor(1,1,1,1)
	memberLabel:SetPoint("TOPLEFT",162,0)

	local nameLabel = frame:CreateFontString(nil,"ARTWORK","GameFontNormalSmall")
	nameLabel:SetWidth(160)
	nameLabel:SetHeight(16)
	nameLabel:SetJustifyH("LEFT")
	nameLabel:SetTextColor(1,1,1,1)
	nameLabel:SetPoint("TOPLEFT",162,0)


	-- create widget
	local widget = {
		numLabel = numLabel,
		dateLabel = dateLabel,
		memberLabel = memberLabel,
		frame = frame,
		type  = Type
	}
	for method, func in pairs(methods) do
		widget[method] = func
	end
	return AceGUI:RegisterAsWidget(widget)
end

AceGUI:RegisterWidgetType(Type, Constructor, Version)
