--[[-----------------------------------------------------------------------------
HeadCount Raid Item Widget
-------------------------------------------------------------------------------]]
local Type, Version = "HeadCountHeaderItem", 1
local AceGUI = LibStub and LibStub("AceGUI-3.0", true)
if not AceGUI or (AceGUI:GetWidgetVersion(Type) or 0) >= Version then return end

-- Lua APIs
local max, select, pairs = math.max, select, pairs

-- WoW APIs
local CreateFrame, UIParent = CreateFrame, UIParent


local function UpdateLabelAnchors(self)
	local content = self.frame
	local frameoffset
	local lastframeoffset
	for i=1,10 do
		local child = self.columns[i]
		local frameheight = child.height or child:GetHeight() or 0
		local framewidth = child.width or child:GetWidth() or 0
		lastframeoffset = frameoffset
		frameoffset = child.alignoffset or (frameheight / 2)
		child:ClearAllPoints()
		if i == 1 then
			child:SetPoint("TOPLEFT", content, 8, 0)
		else
			child:SetPoint("TOPLEFT", self.columns[i-1], "TOPRIGHT", 0, frameoffset - lastframeoffset)
		end
	end
end

--[[-----------------------------------------------------------------------------
Methods
-------------------------------------------------------------------------------]]
local methods = {
	["OnAcquire"] = function(self)
		self:SetWidth(500)
		for i=1,10 do
			self:SetColumn(i,"","",50)
		end
	end,

	["OnRelease"] = function(self)

	end,

	["OnWidthSet"] = function(self, width)
		self.frame:SetWidth(width)
	end,


	["SetColumn"] = function(self, index, name, colName, width, tooltip)
		self.columns[index]:SetText(name)
		self.columns[index].colName = colName
		self.columns[index]:SetWidth(width)
		self.columns[index].tt = tooltip
		if strlen(name) > 0 then
			self.columns[index]:Show()
		end
		UpdateLabelAnchors(self)
	end,

}


local function Column_OnClick(frame)
	if strlen(frame.colName) > 0 then
		frame.obj:Fire("SortChosen",frame.colName)
		AceGUI:ClearFocus()
	end
end

local function Button_OnEnter(frame)
	if frame.tt and strlen(frame.tt) > 0 then
		GameTooltip:SetOwner(frame,"ANCHOR_CURSOR", -6, 0)
		GameTooltip:AddLine(string.format("|cFF9999FF%s|r",frame.tt))
		GameTooltip:Show()
	end
end

local function Button_OnLeave(frame)
	GameTooltip:Hide()
end
--[[-----------------------------------------------------------------------------
Constructor
-------------------------------------------------------------------------------]]
local function Constructor()
	local frame = CreateFrame("Frame", nil, UIParent)
	frame:Hide()
	frame:SetWidth(596)
	frame:SetHeight(18)

	local labels = {}
	local lastAnchor = frame
	for i=1,10 do
		local lframe = CreateFrame("Button", nil, frame)
		lframe:Hide()
		lframe:SetHeight(18)
		lframe:SetText("")
		lframe:EnableMouse(true)
		lframe:SetScript("OnEnter",Button_OnEnter)
		lframe:SetScript("OnLeave",Button_OnLeave)
		lframe:SetScript("OnClick",Column_OnClick)
		lframe:SetPoint("TOPLEFT",lastAnchor)
		lframe:SetNormalFontObject("HeaderTitle")
		lastAnchor = lframe
		tinsert(labels,lframe)
	end
	-- create widget
	local widget = {
		frame = frame,
		type  = Type,
		columns = labels,
	}
	for method, func in pairs(methods) do
		widget[method] = func
	end
	for i=1,10 do
		labels[i].obj = widget
	end
	return AceGUI:RegisterAsWidget(widget)
end

AceGUI:RegisterWidgetType(Type, Constructor, Version)
